@@ -9,4 +9,5 @@ from .icu.number import *  # noqa
 # TODO: Remove src/icupy/number.py in a future release.
 warnings.warn(
     "icupy.number module is deprecated. Use icupy.icu.number instead.",
-    stacklevel=2)
+    stacklevel=2,
+)
