@@ -11,10 +11,10 @@ void init_measure(py::module &m) {
   // icu::Measure
   py::class_<Measure, UObject> meas(m, "Measure");
   meas.def(py::init([](const Formattable &number, const MeasureUnit *adopted_unit) {
-             UErrorCode error_code = U_ZERO_ERROR;
+             ErrorCode error_code;
              auto result = std::make_unique<Measure>(
                  number, reinterpret_cast<MeasureUnit *>(adopted_unit ? adopted_unit->clone() : nullptr), error_code);
-             if (U_FAILURE(error_code)) {
+             if (error_code.isFailure()) {
                throw ICUError(error_code);
              }
              return result;
@@ -32,18 +32,18 @@ void init_measure(py::module &m) {
   // icu::CurrencyAmount
   py::class_<CurrencyAmount, Measure> ca(m, "CurrencyAmount");
   ca.def(py::init([](const Formattable &amount, const char16_t *iso_code) {
-           UErrorCode error_code = U_ZERO_ERROR;
+           ErrorCode error_code;
            auto result = std::make_unique<CurrencyAmount>(amount, iso_code, error_code);
-           if (U_FAILURE(error_code)) {
+           if (error_code.isFailure()) {
              throw ICUError(error_code);
            }
            return result;
          }),
          py::arg("amount"), py::arg("iso_code").none(false))
       .def(py::init([](double amount, const char16_t *iso_code) {
-             UErrorCode error_code = U_ZERO_ERROR;
+             ErrorCode error_code;
              auto result = std::make_unique<CurrencyAmount>(amount, iso_code, error_code);
-             if (U_FAILURE(error_code)) {
+             if (error_code.isFailure()) {
                throw ICUError(error_code);
              }
              return result;
@@ -60,18 +60,18 @@ void init_measure(py::module &m) {
   // icu::TimeUnitAmount
   py::class_<TimeUnitAmount, Measure> tua(m, "TimeUnitAmount");
   tua.def(py::init([](const Formattable &number, TimeUnit::UTimeUnitFields time_unit_field) {
-            UErrorCode error_code = U_ZERO_ERROR;
+            ErrorCode error_code;
             auto result = std::make_unique<TimeUnitAmount>(number, time_unit_field, error_code);
-            if (U_FAILURE(error_code)) {
+            if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
             return result;
           }),
           py::arg("number"), py::arg("time_unit_field"))
       .def(py::init([](double amount, TimeUnit::UTimeUnitFields time_unit_field) {
-             UErrorCode error_code = U_ZERO_ERROR;
+             ErrorCode error_code;
              auto result = std::make_unique<TimeUnitAmount>(amount, time_unit_field, error_code);
-             if (U_FAILURE(error_code)) {
+             if (error_code.isFailure()) {
                throw ICUError(error_code);
              }
              return result;
