@@ -10,9 +10,9 @@ void init_resbund(py::module &m) {
   res.def(
          // [1] ResourceBundle::ResourceBundle
          py::init([](const UnicodeString &package_name, const Locale &locale) {
-           UErrorCode error_code = U_ZERO_ERROR;
+           ErrorCode error_code;
            auto result = std::make_unique<ResourceBundle>(package_name, locale, error_code);
-           if (U_FAILURE(error_code)) {
+           if (error_code.isFailure()) {
              throw ICUError(error_code);
            }
            return result;
@@ -21,9 +21,9 @@ void init_resbund(py::module &m) {
       .def(
           // const char *locale -> const Locale &locale
           py::init([](const UnicodeString &package_name, const char *locale) {
-            UErrorCode error_code = U_ZERO_ERROR;
+            ErrorCode error_code;
             auto result = std::make_unique<ResourceBundle>(package_name, locale, error_code);
-            if (U_FAILURE(error_code)) {
+            if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
             return result;
@@ -32,9 +32,9 @@ void init_resbund(py::module &m) {
       .def(
           // [2] ResourceBundle::ResourceBundle
           py::init([](const UnicodeString &package_name) {
-            UErrorCode error_code = U_ZERO_ERROR;
+            ErrorCode error_code;
             auto result = std::make_unique<ResourceBundle>(package_name, error_code);
-            if (U_FAILURE(error_code)) {
+            if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
             return result;
@@ -43,9 +43,9 @@ void init_resbund(py::module &m) {
       .def(
           // const char16_t *package_name -> const UnicodeString &package_name
           py::init([](const char16_t *package_name) {
-            UErrorCode error_code = U_ZERO_ERROR;
+            ErrorCode error_code;
             auto result = std::make_unique<ResourceBundle>(package_name, error_code);
-            if (U_FAILURE(error_code)) {
+            if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
             return result;
@@ -54,9 +54,9 @@ void init_resbund(py::module &m) {
       .def(
           // [3] ResourceBundle::ResourceBundle
           py::init([]() {
-            UErrorCode error_code = U_ZERO_ERROR;
+            ErrorCode error_code;
             auto result = std::make_unique<ResourceBundle>(error_code);
-            if (U_FAILURE(error_code)) {
+            if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
             return result;
@@ -64,9 +64,9 @@ void init_resbund(py::module &m) {
       .def(
           // [4] ResourceBundle::ResourceBundle
           py::init([](const char *package_name, const Locale &locale) {
-            UErrorCode error_code = U_ZERO_ERROR;
+            ErrorCode error_code;
             auto result = std::make_unique<ResourceBundle>(package_name, locale, error_code);
-            if (U_FAILURE(error_code)) {
+            if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
             return result;
@@ -75,9 +75,9 @@ void init_resbund(py::module &m) {
       .def(
           // const char *locale -> const Locale &locale
           py::init([](const char *package_name, const char *locale) {
-            UErrorCode error_code = U_ZERO_ERROR;
+            ErrorCode error_code;
             auto result = std::make_unique<ResourceBundle>(package_name, locale, error_code);
-            if (U_FAILURE(error_code)) {
+            if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
             return result;
@@ -89,9 +89,9 @@ void init_resbund(py::module &m) {
       .def(
           // [6] ResourceBundle::ResourceBundle
           py::init([](_UResourceBundlePtr &res) {
-            UErrorCode error_code = U_ZERO_ERROR;
+            ErrorCode error_code;
             auto result = std::make_unique<ResourceBundle>(res, error_code);
-            if (U_FAILURE(error_code)) {
+            if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
             return result;
@@ -110,9 +110,9 @@ void init_resbund(py::module &m) {
         if (!self.hasNext()) {
           throw py::stop_iteration();
         }
-        UErrorCode error_code = U_ZERO_ERROR;
+        ErrorCode error_code;
         auto result = self.getNext(error_code);
-        if (U_FAILURE(error_code)) {
+        if (error_code.isFailure()) {
           throw ICUError(error_code);
         }
         return result;
@@ -121,9 +121,9 @@ void init_resbund(py::module &m) {
   res.def(
          "get",
          [](const ResourceBundle &self, const char *key) {
-           UErrorCode error_code = U_ZERO_ERROR;
+           ErrorCode error_code;
            auto result = self.get(key, error_code);
-           if (U_FAILURE(error_code)) {
+           if (error_code.isFailure()) {
              throw ICUError(error_code);
            }
            return result;
@@ -132,37 +132,37 @@ void init_resbund(py::module &m) {
       .def(
           "get",
           [](const ResourceBundle &self, int32_t index) {
-            UErrorCode error_code = U_ZERO_ERROR;
+            ErrorCode error_code;
             auto result = self.get(index, error_code);
-            if (U_FAILURE(error_code)) {
+            if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
             return result;
           },
           py::arg("index"));
   res.def("get_binary", [](const ResourceBundle &self) {
-    UErrorCode error_code = U_ZERO_ERROR;
+    ErrorCode error_code;
     int32_t length;
     auto p = self.getBinary(length, error_code);
-    if (U_FAILURE(error_code)) {
+    if (error_code.isFailure()) {
       throw ICUError(error_code);
     }
     std::vector<uint8_t> result(p, p + length);
     return result;
   });
   res.def("get_int", [](const ResourceBundle &self) {
-    UErrorCode error_code = U_ZERO_ERROR;
+    ErrorCode error_code;
     auto result = self.getInt(error_code);
-    if (U_FAILURE(error_code)) {
+    if (error_code.isFailure()) {
       throw ICUError(error_code);
     }
     return result;
   });
   res.def("get_int_vector", [](const ResourceBundle &self) {
-    UErrorCode error_code = U_ZERO_ERROR;
+    ErrorCode error_code;
     int32_t length;
     auto p = self.getIntVector(length, error_code);
-    if (U_FAILURE(error_code)) {
+    if (error_code.isFailure()) {
       throw ICUError(error_code);
     }
     std::vector<int32_t> result(p, p + length);
@@ -172,9 +172,9 @@ void init_resbund(py::module &m) {
   res.def(
       "get_locale",
       [](const ResourceBundle &self, ULocDataLocaleType type) {
-        UErrorCode error_code = U_ZERO_ERROR;
+        ErrorCode error_code;
         auto result = self.getLocale(type, error_code);
-        if (U_FAILURE(error_code)) {
+        if (error_code.isFailure()) {
           throw ICUError(error_code);
         }
         return result;
@@ -182,26 +182,26 @@ void init_resbund(py::module &m) {
       py::arg("type_"));
   res.def("get_name", &ResourceBundle::getName, py::return_value_policy::reference);
   res.def("get_next", [](ResourceBundle &self) {
-    UErrorCode error_code = U_ZERO_ERROR;
+    ErrorCode error_code;
     auto result = self.getNext(error_code);
-    if (U_FAILURE(error_code)) {
+    if (error_code.isFailure()) {
       throw ICUError(error_code);
     }
     return result;
   });
   res.def("get_next_string", [](ResourceBundle &self) {
-    UErrorCode error_code = U_ZERO_ERROR;
+    ErrorCode error_code;
     auto result = self.getNextString(error_code);
-    if (U_FAILURE(error_code)) {
+    if (error_code.isFailure()) {
       throw ICUError(error_code);
     }
     return result;
   });
   res.def("get_size", &ResourceBundle::getSize);
   res.def("get_string", [](const ResourceBundle &self) {
-    UErrorCode error_code = U_ZERO_ERROR;
+    ErrorCode error_code;
     auto result = self.getString(error_code);
-    if (U_FAILURE(error_code)) {
+    if (error_code.isFailure()) {
       throw ICUError(error_code);
     }
     return result;
@@ -209,9 +209,9 @@ void init_resbund(py::module &m) {
   res.def(
          "get_string_ex",
          [](const ResourceBundle &self, const char *key) {
-           UErrorCode error_code = U_ZERO_ERROR;
+           ErrorCode error_code;
            auto result = self.getStringEx(key, error_code);
-           if (U_FAILURE(error_code)) {
+           if (error_code.isFailure()) {
              throw ICUError(error_code);
            }
            return result;
@@ -220,9 +220,9 @@ void init_resbund(py::module &m) {
       .def(
           "get_string_ex",
           [](const ResourceBundle &self, int32_t index) {
-            UErrorCode error_code = U_ZERO_ERROR;
+            ErrorCode error_code;
             auto result = self.getStringEx(index, error_code);
-            if (U_FAILURE(error_code)) {
+            if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
             return result;
@@ -230,9 +230,9 @@ void init_resbund(py::module &m) {
           py::arg("index"));
   res.def("get_type", &ResourceBundle::getType);
   res.def("get_uint", [](const ResourceBundle &self) {
-    UErrorCode error_code = U_ZERO_ERROR;
+    ErrorCode error_code;
     auto result = self.getUInt(error_code);
-    if (U_FAILURE(error_code)) {
+    if (error_code.isFailure()) {
       throw ICUError(error_code);
     }
     return result;
