@@ -19,9 +19,9 @@ void init_uenum(py::module &m) {
   m.def(
       "uenum_count",
       [](_UEnumerationPtr &en) {
-        UErrorCode error_code = U_ZERO_ERROR;
-        auto result = uenum_count(en, &error_code);
-        if (U_FAILURE(error_code)) {
+        ErrorCode error_code;
+        auto result = uenum_count(en, error_code);
+        if (error_code.isFailure()) {
           throw ICUError(error_code);
         }
         return result;
@@ -30,9 +30,9 @@ void init_uenum(py::module &m) {
   m.def(
       "uenum_next",
       [](_UEnumerationPtr &en) {
-        UErrorCode error_code = U_ZERO_ERROR;
-        auto result = uenum_next(en, nullptr, &error_code);
-        if (U_FAILURE(error_code)) {
+        ErrorCode error_code;
+        auto result = uenum_next(en, nullptr, error_code);
+        if (error_code.isFailure()) {
           throw ICUError(error_code);
         }
         return result;
@@ -45,14 +45,14 @@ void init_uenum(py::module &m) {
         if (count == -1) {
           count = static_cast<int32_t>(strings.size());
         }
-        UErrorCode error_code = U_ZERO_ERROR;
+        ErrorCode error_code;
         auto source = std::shared_ptr<char *[]>(new char *[strings.size()], std::default_delete<char *[]>());
         auto s = source.get();
         for (size_t n = 0; n < strings.size(); ++n, ++s) {
           *s = strdup(strings[n].c_str());
         }
-        auto p = uenum_openCharStringsEnumeration(source.get(), count, &error_code);
-        if (U_FAILURE(error_code)) {
+        auto p = uenum_openCharStringsEnumeration(source.get(), count, error_code);
+        if (error_code.isFailure()) {
           throw ICUError(error_code);
         }
         return std::make_unique<_UEnumerationPtr>(p, source);
@@ -62,9 +62,9 @@ void init_uenum(py::module &m) {
   m.def(
       "uenum_open_from_string_enumeration",
       [](StringEnumeration *adopted) {
-        UErrorCode error_code = U_ZERO_ERROR;
-        auto p = uenum_openFromStringEnumeration(adopted ? adopted->clone() : nullptr, &error_code);
-        if (U_FAILURE(error_code)) {
+        ErrorCode error_code;
+        auto p = uenum_openFromStringEnumeration(adopted ? adopted->clone() : nullptr, error_code);
+        if (error_code.isFailure()) {
           throw ICUError(error_code);
         }
         return std::make_unique<_UEnumerationPtr>(p);
@@ -77,15 +77,15 @@ void init_uenum(py::module &m) {
         if (count == -1) {
           count = static_cast<int32_t>(strings.size());
         }
-        UErrorCode error_code = U_ZERO_ERROR;
+        ErrorCode error_code;
         auto source = std::shared_ptr<UChar *[]>(new UChar *[strings.size()], std::default_delete<UChar *[]>());
         auto s = source.get();
         for (size_t n = 0; n < strings.size(); ++n, ++s) {
           *s = new UChar[strings[n].size() + 1];
           u_strcpy(*s, strings[n].c_str());
         }
-        auto p = uenum_openUCharStringsEnumeration(source.get(), count, &error_code);
-        if (U_FAILURE(error_code)) {
+        auto p = uenum_openUCharStringsEnumeration(source.get(), count, error_code);
+        if (error_code.isFailure()) {
           throw ICUError(error_code);
         }
         return std::make_unique<_UEnumerationPtr>(p, source);
@@ -95,9 +95,9 @@ void init_uenum(py::module &m) {
   m.def(
       "uenum_reset",
       [](_UEnumerationPtr &en) {
-        UErrorCode error_code = U_ZERO_ERROR;
-        uenum_reset(en, &error_code);
-        if (U_FAILURE(error_code)) {
+        ErrorCode error_code;
+        uenum_reset(en, error_code);
+        if (error_code.isFailure()) {
           throw ICUError(error_code);
         }
       },
@@ -105,9 +105,9 @@ void init_uenum(py::module &m) {
   m.def(
       "uenum_unext",
       [](_UEnumerationPtr &en) {
-        UErrorCode error_code = U_ZERO_ERROR;
-        auto result = uenum_unext(en, nullptr, &error_code);
-        if (U_FAILURE(error_code)) {
+        ErrorCode error_code;
+        auto result = uenum_unext(en, nullptr, error_code);
+        if (error_code.isFailure()) {
           throw ICUError(error_code);
         }
         return result;
