@@ -1,13 +1,17 @@
 import copy
 
 import pytest
+
+# fmt: off
 from icupy.icu import (
-    Calendar, DateFormat, FieldPosition, FieldPositionIterator,
-    Format, Formattable, GregorianCalendar, ICUError, Locale, NumberFormat,
-    ParsePosition, TimeZone, UDateFormatField, UErrorCode,
-    ULocDataLocaleType, U_ICU_VERSION_MAJOR_NUM, UnicodeString,
+    U_ICU_VERSION_MAJOR_NUM, Calendar, DateFormat, FieldPosition,
+    FieldPositionIterator, Format, Formattable, GregorianCalendar, ICUError,
+    Locale, NumberFormat, ParsePosition, TimeZone, UDateFormatField,
+    UErrorCode, ULocDataLocaleType, UnicodeString,
 )
 
+# fmt: on
+
 
 def test_api():
     assert issubclass(DateFormat, Format)
@@ -20,17 +24,14 @@ def test_api():
 
     zone = TimeZone.create_default()
     fmt = DateFormat.create_date_time_instance(
-        DateFormat.DEFAULT,
-        DateFormat.DEFAULT,
-        Locale.get_english())
+        DateFormat.DEFAULT, DateFormat.DEFAULT, Locale.get_english()
+    )
     fmt2 = DateFormat.create_date_time_instance(
-        DateFormat.DEFAULT,
-        DateFormat.DEFAULT,
-        Locale.get_english())
+        DateFormat.DEFAULT, DateFormat.DEFAULT, Locale.get_english()
+    )
     fmt3 = DateFormat.create_date_time_instance(
-        DateFormat.SHORT,
-        DateFormat.LONG,
-        Locale.get_english())
+        DateFormat.SHORT, DateFormat.LONG, Locale.get_english()
+    )
 
     # UBool icu::Format::operator!=(const Format &)
     assert not (fmt != fmt2)
@@ -122,8 +123,8 @@ def test_create_instance():
     assert isinstance(fmt1a, DateFormat)
 
     fmt1b = DateFormat.create_date_instance(
-        DateFormat.DEFAULT,
-        Locale.get_default())
+        DateFormat.DEFAULT, Locale.get_default()
+    )
     assert isinstance(fmt1b, DateFormat)
     assert fmt1 == fmt1a == fmt1b
 
@@ -139,14 +140,13 @@ def test_create_instance():
     assert isinstance(fmt2a, DateFormat)
 
     fmt2b = DateFormat.create_date_time_instance(
-        DateFormat.DEFAULT,
-        DateFormat.DEFAULT)
+        DateFormat.DEFAULT, DateFormat.DEFAULT
+    )
     assert isinstance(fmt2b, DateFormat)
 
     fmt2c = DateFormat.create_date_time_instance(
-        DateFormat.DEFAULT,
-        DateFormat.DEFAULT,
-        Locale.get_default())
+        DateFormat.DEFAULT, DateFormat.DEFAULT, Locale.get_default()
+    )
     assert isinstance(fmt2c, DateFormat)
     assert fmt2 == fmt2a == fmt2b == fmt2c
 
@@ -155,9 +155,8 @@ def test_create_instance():
     assert isinstance(fmt3, DateFormat)
 
     fmt2d = DateFormat.create_date_time_instance(
-        DateFormat.SHORT,
-        DateFormat.SHORT,
-        Locale.get_default())
+        DateFormat.SHORT, DateFormat.SHORT, Locale.get_default()
+    )
     assert isinstance(fmt2d, DateFormat)
     assert fmt3 == fmt2d
 
@@ -172,8 +171,8 @@ def test_create_instance():
     assert isinstance(fmt4a, DateFormat)
 
     fmt4b = DateFormat.create_time_instance(
-        DateFormat.DEFAULT,
-        Locale.get_default())
+        DateFormat.DEFAULT, Locale.get_default()
+    )
     assert isinstance(fmt4b, DateFormat)
     assert fmt4 == fmt4a == fmt4b
 
@@ -187,13 +186,13 @@ def test_create_instance_for_skeleton():
     #       UErrorCode &status
     # )
     fmt2 = DateFormat.create_instance_for_skeleton(
-        UnicodeString("yMMMMd"),
-        Locale.get_english())
+        UnicodeString("yMMMMd"), Locale.get_english()
+    )
     assert isinstance(fmt2, DateFormat)
 
     fmt2a = DateFormat.create_instance_for_skeleton(
-        "yMMMMd",
-        Locale.get_english())
+        "yMMMMd", Locale.get_english()
+    )
     assert isinstance(fmt2a, DateFormat)
     assert fmt2 == fmt2a
 
@@ -216,9 +215,8 @@ def test_format():
     cal = GregorianCalendar(zone)
     cal.set_time(date)
     fmt = DateFormat.create_date_time_instance(
-        DateFormat.MEDIUM,
-        DateFormat.SHORT,
-        Locale.get_english())
+        DateFormat.MEDIUM, DateFormat.SHORT, Locale.get_english()
+    )
     fmt.set_time_zone(zone)
 
     # [1]
@@ -388,16 +386,16 @@ def test_get_boolean_attribute():
     from icupy.icu import UDateFormatBooleanAttribute
 
     fmt = DateFormat.create_date_time_instance(
-        DateFormat.MEDIUM,
-        DateFormat.SHORT,
-        Locale.get_english())
+        DateFormat.MEDIUM, DateFormat.SHORT, Locale.get_english()
+    )
 
     # UBool icu::DateFormat::getBooleanAttribute(
     #       UDateFormatBooleanAttribute attr,
     #       UErrorCode &status
     # )
     assert fmt.get_boolean_attribute(
-        UDateFormatBooleanAttribute.UDAT_PARSE_ALLOW_WHITESPACE)
+        UDateFormatBooleanAttribute.UDAT_PARSE_ALLOW_WHITESPACE
+    )
 
     # DateFormat &icu::DateFormat::setBooleanAttribute(
     #       UDateFormatBooleanAttribute attr,
@@ -405,12 +403,13 @@ def test_get_boolean_attribute():
     #       UErrorCode &status
     # )
     result = fmt.set_boolean_attribute(
-        UDateFormatBooleanAttribute.UDAT_PARSE_ALLOW_WHITESPACE,
-        False)
+        UDateFormatBooleanAttribute.UDAT_PARSE_ALLOW_WHITESPACE, False
+    )
     assert isinstance(result, DateFormat)
     assert id(result) == id(fmt)
     assert not fmt.get_boolean_attribute(
-        UDateFormatBooleanAttribute.UDAT_PARSE_ALLOW_WHITESPACE)
+        UDateFormatBooleanAttribute.UDAT_PARSE_ALLOW_WHITESPACE
+    )
 
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 53, reason="ICU4C<53")
@@ -418,25 +417,29 @@ def test_get_context():
     from icupy.icu import UDisplayContext, UDisplayContextType
 
     fmt = DateFormat.create_date_time_instance(
-        DateFormat.MEDIUM,
-        DateFormat.SHORT,
-        Locale.get_english())
+        DateFormat.MEDIUM, DateFormat.SHORT, Locale.get_english()
+    )
 
     # UDisplayContext icu::DateFormat::getContext(
     #       UDisplayContextType type,
     #       UErrorCode &status
     # )
-    assert (fmt.get_context(UDisplayContextType.UDISPCTX_TYPE_CAPITALIZATION)
-            == UDisplayContext.UDISPCTX_CAPITALIZATION_NONE)
+    assert (
+        fmt.get_context(UDisplayContextType.UDISPCTX_TYPE_CAPITALIZATION)
+        == UDisplayContext.UDISPCTX_CAPITALIZATION_NONE
+    )
 
     # void icu::DateFormat::setContext(
     #       UDisplayContext value,
     #       UErrorCode &status
     # )
     fmt.set_context(
-        UDisplayContext.UDISPCTX_CAPITALIZATION_FOR_MIDDLE_OF_SENTENCE)
-    assert (fmt.get_context(UDisplayContextType.UDISPCTX_TYPE_CAPITALIZATION)
-            == UDisplayContext.UDISPCTX_CAPITALIZATION_FOR_MIDDLE_OF_SENTENCE)
+        UDisplayContext.UDISPCTX_CAPITALIZATION_FOR_MIDDLE_OF_SENTENCE
+    )
+    assert (
+        fmt.get_context(UDisplayContextType.UDISPCTX_TYPE_CAPITALIZATION)
+        == UDisplayContext.UDISPCTX_CAPITALIZATION_FOR_MIDDLE_OF_SENTENCE
+    )
 
 
 def test_get_time_zone_upcasting():
@@ -458,9 +461,8 @@ def test_get_time_zone_upcasting():
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 53, reason="ICU4C<53")
 def test_is_calendar_lenient():
     fmt = DateFormat.create_date_time_instance(
-        DateFormat.MEDIUM,
-        DateFormat.SHORT,
-        Locale.get_english())
+        DateFormat.MEDIUM, DateFormat.SHORT, Locale.get_english()
+    )
 
     # UBool icu::DateFormat::isCalendarLenient(void)
     assert fmt.is_calendar_lenient()
@@ -476,9 +478,8 @@ def test_is_calendar_lenient():
 
 def test_parse():
     fmt = DateFormat.create_date_time_instance(
-        DateFormat.SHORT,
-        DateFormat.LONG,
-        Locale.get_english())
+        DateFormat.SHORT, DateFormat.LONG, Locale.get_english()
+    )
 
     # [1]
     # void icu::DateFormat::parse(
@@ -537,9 +538,8 @@ def test_parse():
 
 def test_parse_object():
     fmt = DateFormat.create_date_time_instance(
-        DateFormat.SHORT,
-        DateFormat.LONG,
-        Locale.get_english())
+        DateFormat.SHORT, DateFormat.LONG, Locale.get_english()
+    )
 
     # void icu::DateFormat::parseObject(
     #       const UnicodeString &source,
@@ -548,18 +548,14 @@ def test_parse_object():
     # )
     result = Formattable()
     parse_pos = ParsePosition(0)
-    fmt.parse_object(UnicodeString("07/10/96 4:5:0 PM PDT"),
-                     result,
-                     parse_pos)
+    fmt.parse_object(UnicodeString("07/10/96 4:5:0 PM PDT"), result, parse_pos)
     assert parse_pos.get_error_index() == -1
     assert result.get_type() == Formattable.DATE
     assert result.get_date() == 837039900000.0  # 1996-07-10T16:05:00-07:00
 
     result = Formattable()
     parse_pos = ParsePosition(0)
-    fmt.parse_object("07/10/96 4:5:0 PM PDT",
-                     result,
-                     parse_pos)
+    fmt.parse_object("07/10/96 4:5:0 PM PDT", result, parse_pos)
     assert parse_pos.get_error_index() == -1
     assert result.get_type() == Formattable.DATE
     assert result.get_date() == 837039900000.0  # 1996-07-10T16:05:00-07:00
